#
# spec file for package hdjmod
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2021 Matthias Bach <marix@marix.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hdjmod
Version:        1.37
Release:        1.1.2.3.sr20250501
Summary:        Support for Hercules DJ Devices
License:        GPL-2.0-or-later
Group:          System/Kernel
URL:            https://codeberg.org/Marix/hdjmod
Source0:        https://codeberg.org/Marix/hdjmod/archive/%{version}.tar.gz#/hdjmod-%{version}.tar.gz
Source1:        preamble
BuildRequires:  modutils kernel-syms kmod-compat suse-kernel-rpm-scriptlets bash-sh kernel-syms-longterm
BuildRequires:  libelf-devel
%suse_kernel_module_package -p%{_sourcedir}/preamble

%description
This is the Hercules DJ Series Kernel Module, which supports Hercules DJ Devices.

%prep
echo %{flavors_to_build}

%setup -q -n %{name}

set -- *
mkdir source
mv "$@" source/
mkdir obj

%build
for flavor in %{flavors_to_build}; do
        rm -rf obj/$flavor
        cp -r source obj/$flavor
        %make_build -C %{kernel_source $flavor} %{?linux_make_arch} modules M=$PWD/obj/$flavor
done

%install
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=updates
for flavor in %{flavors_to_build}; do
        make -C %{kernel_source $flavor} %{?linux_make_arch} modules_install M=$PWD/obj/$flavor
done

%changelog
* Tue Apr 15 2025 Matthias Bach <marix@marix.org> - 1.37
- Update to version 1.37
  * Compatibility with Linux 6.15
- Add service file to download source files based on spec file
* Thu Oct  3 2024 Matthias Bach <marix@marix.org> - 1.36
- Update to version 1.36
  * Compatibility with Linux 6.12
* Thu Aug 29 2024 Matthias Bach <marix@marix.org> - 1.35
- Update to version 1.35
  * Compatibility with GCC 14
* Wed May 10 2023 Matthias Bach <marix@marix.org> - 1.34
- Update to version 1.34
  * Compatibility with Linux 6.4
- Drop hdjmod_fix_hotplug.patch that has been included upstream.
* Mon Jun 20 2022 Matthias Bach <marix@marix.org> - 1.33
- Update to version 1.33
  * Compatibility with Linux 5.19
* Sat Jun  5 2021 Matthias Bach <marix@marix.org> - 1.32
- Update to version 1.32
  * Adds support for the Hercules Steel controller.
- Switch to fork maintained at https://codeberg.org/Marix/hdjmod.
  * Consolidates fixes made for openSUSE and Ubuntu packages,
    providing support for newer kernel up to including Linux 5.12
    without having to maintain a series of patch files.
- Dropped obsolete patches:
  * hdjmod_fix_buffer_overrun_in_device_name_handling.patch
  * hdjmod_kernel_2.6.30.patch
  * hdjmod_kernel_2.6.36.patch.bz2
  * hdjmod_kernel_2.6.37.patch
  * hdjmod_kernel_2.6.39.patch
  * hdjmod_kernel_3.6.patch
  * hdjmod_kernel_3.7.patch
  * hdjmod_kernel_3.16.patch
  * hdjmod_kernel_4.11.patch
  * hdjmod_kernel_4.14.patch
  * hdjmod_kernel_4.15.patch
  * hdjmod_kernel_5.0.patch
  * hdjmod_kernel_5.12.patch
  * hdjmod-kfree.patch
* Sat May  8 2021 Matthias Bach <marix@marix.org>
- Added hdjmod_kernel_5.12.patch to fix build against Linux 5.12.
* Thu Dec 24 2020 Matthias Bach <marix@marix.org>
- Make package conform to spec-cleaner
- Drop support for ancient openSUSE versions
* Mon Mar 18 2019 Michal Suchanek <msuchanek@suse.com>
- Fix build with kernel 5.0:
  * hdjmod_kernel_5.0.patch
* Tue Jun 19 2018 msuchanek@suse.com
- Use %%{?linux_make_arch} when building kernel modules (boo#1098050).
* Sat Feb 10 2018 marix@marix.org
- Added hdjmod_kernel_4.15.patch: Fixes build on Kernel 4.15 and
  up.
- Removed accidentally added backup file from
  hdjmod_fix_hotplug.patch
* Sun Nov 26 2017 marix@marix.org
- Added hdjmod_kernel_4.14.patch: Fixes build on Kernel 4.14 and
  up.
* Sat Jul  1 2017 marix@marix.org
- Added hdjmod_fix_buffer_overrun_in_device_name_handling.patch:
  Fixes a potential buffer overrun in device name handling.
* Fri May 26 2017 marix@marix.org
- Added hdjmod_kernel_4.11.patch: Fixes build on Kernel 4.11 and
  up.
* Fri Jul 25 2014 marix@marix.org
- Fixed build on kernel 3.16
  The required patch is hdjmod_kernel_3.16.patch
* Sun Dec 23 2012 marix@marix.org
- Fixed build on kernel 3.7
* Tue Oct 16 2012 marix@marix.org
- Fixed build on kernel 3.6
* Sat Apr  7 2012 marix@marix.org
- Fixed build on SLE 11 SP 2
* Tue Mar 13 2012 marix@marix.org
- Fixed USB hotplugging
  Previously the module also loaded for devices of other vendors.
* Wed Aug  3 2011 cfarrell@novell.com
- license update: GPL-2.0+
  Specify the license more accurately using the appropriate syntax
* Mon May 30 2011 marix@marix.org
- Fixed build on kernels newer than openSUSE 11.4
* Sat Apr 30 2011 marix@marix.org
- Fixed build on SLE 11 SP 1
* Sat Apr 30 2011 marix@marix.org
- Cleaned up spec file
- Fixed missing dependency to the kernel
* Thu Dec  2 2010 marix@marix.org
- Patched to fix build with kernel 2.6.37
* Sun Sep 26 2010 marix@marix.org
- Patched to fix build with kernels newer than openSUSE 11.3
* Sun Jul 25 2010 marix@marix.org
- Build for older openSUSE versions
* Sun Jul 25 2010 marix@marix.org
- Initial version
